""" sample docstring

$DESCRIPTION

$AUTHOR

"""

# sample import
import argparse


def main():
    """ A sample main method """
    pass

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="$DESCRIPTION")
    exit(main())
